@@ -5,9 +5,16 @@ use strict;
 use Time::HiRes qw(time);
 use Graphics::Framebuffer;
 
-my $f = Graphics::Framebuffer->new('FILE_MODE' => 0, 'FB_DEVICE' => '/dev/fb0');
+my $args = join('',@ARGV);
 
-my $fm = Graphics::Framebuffer->new('FILE_MODE' => 1, 'FB_DEVICE' => '/dev/fb0', 'SPLASH' => 0);
+my $dev = 0;
+if ($args =~ /(\d+)/) {
+    $dev = $1;
+}
+
+my $f = Graphics::Framebuffer->new('FILE_MODE' => 0, 'FB_DEVICE' => "/dev/fb$dev");
+
+my $fm = Graphics::Framebuffer->new('FILE_MODE' => 1, 'FB_DEVICE' => "/dev/fb$dev", 'SPLASH' => 0);
 
 $f->cls('OFF');
 my @t;
@@ -65,4 +72,4 @@ foreach my $xx (0 .. $f->{'XRES'}) {
 push(@t, sprintf('%.02f', time - $start));
 $f->cls('ON');
 
-print "CIRCLE STRING: $t[0]\n  CIRCLE FILE: $t[1]\n   BOX STRING: $t[2]\n     BOX FILE: $t[3]\n  LINE STRING: $t[4]\n    LINE FILE: $t[5]\n\n";
+print STDERR "CIRCLE STRING: $t[0]\n  CIRCLE FILE: $t[1]\n   BOX STRING: $t[2]\n     BOX FILE: $t[3]\n  LINE STRING: $t[4]\n    LINE FILE: $t[5]\n\n";
