@@ -30,7 +30,7 @@ if ($arg =~ /Y(\d+)/) {
 if (defined($new_x)) {
     $F = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev",'FILE_MODE' => $file, 'SHOW_ERRORS' => 1, 'SIMULATED_X' => $new_x,'SIMULATED_Y' => $new_y);
 } else {
-    $F = Graphics::Framebuffer->new('SPLASH' => 0,'FB_DEVICE' => "/dev/fb$dev",'FILE_MODE' => $file, 'SHOW_ERRORS' => 1);
+    $F = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev",'FILE_MODE' => $file, 'SHOW_ERRORS' => 1);
 }
 
 $SIG{'QUIT'} = sub {$F->clip_reset();$F->cls('ON'); exit(0);};
